set -x

#******************************************************************************
# Arianna Bisazza @ FBK-irst. April 2012
#******************************************************************************
# Wrapper script for hybrid corpus preparation. See README file in this folder.


#################
# Training corpus
corpus=example/minitrain.en
# NOTE: the corresponding tokenized and possibly lowercased version ($corpus.tok 
# or $corpus.tok.lc) must be in the same directory as $corpus
#################
# Dependencies -- set the following paths
HYBRIDLM=/path-to-hybrid-lm-scripts
IRSTLM=/path-to-irstlm
TREETAGGER=/path-to-treetagger
ttag_en=$TREETAGGER/cmd/tree-tagger-english
ttag_fr=$TREETAGGER/cmd/tree-tagger-french-utf8
#################
# Language -- uncomment one of the following
#LANGUAGE=fr
LANGUAGE=en
#################
# Min. frequency for hybrid mapping -- uncomment one of the following
MINFREQ=20
#################
# Use word surface or lemma -- uncomment one of the following
USE_LEMMA="no";  lemma_suff="";   lemma_param=""
#USE_LEMMA="yes"; lemma_suff="LL"; lemma_param="--lemma --lemma-map"
#################
# Case -- uncomment one of the following
CASE_MODE="all-cased"     # $corpus.tok    expected to be in same directory as $corpus
#CASE_MODE="all-lc"        # $corpus.tok.lc expected to be in same directory as $corpus
#################

#################
#     STEPS     #
#################
DO_TAG=1
DO_DICT=1
DO_POS_MAPPING=1
DO_LEMMA_DICT=1
DO_HYBRID_MAPPING=1
DO_MAP_CORPUS=1
DO_SENT=1
##########################################################

wdir=`pwd`

lg_param="--lg=$LANGUAGE"
ttag=""
if   [ $LANGUAGE == "en" ]; then
    ttag=$ttag_en
elif [ $LANGUAGE == "fr" ]; then
    ttag=$ttag_fr
else
    echo "SUPPORTED LANGUAGES ARE ENGLISH (en) AND FRENCH (fr)"
    exit
fi

#####

if   [ $CASE_MODE == "all-lc" ]; then
    CORPUSTYPE="LC"
    FREQTYPE=""
elif [ $CASE_MODE == "all-cased" ]; then
    CORPUSTYPE=""
    FREQTYPE=""
else
    echo "CHOOSE LOWERCASE OPTION: all-lc|all-cased"; echo""
    exit
fi

case_suff=""
posmap_params=""
if [ $CORPUSTYPE == "LC" ]; then
    case_suff=".lc"
    posmap_params="--lc"
fi

hybmap_suff=hyb$lemma_suff$MINFREQ$FREQTYPE
hybmap_params=""
if [ $FREQTYPE == "LC" ]; then
    hybmap_params="--lc"
fi

#####

if   [ $USE_LEMMA == "no" ]; then
    DO_LEMMA_DICT=0
fi


### INPUT FILES:
corpus_tok=$corpus.tok${case_suff}

### OUTPUT FILES:
corpus_ttagged=$corpus.ttagged
corpus_dict=$corpus.tok${case_suff}.dict
word_tag_map=$corpus.tok${case_suff}.word-tag-map
word_tag_lemma_map=$corpus.tok${case_suff}.word-tag-lemma-map

##########################################################
##########################################################

if [ $DO_TAG == 1 ]; then
# Tag corpus
#cat $corpus | sed -r 's/’/'\''/g;s/´/'\''/g' | $ttag > $corpus_ttagged
cat $corpus | $ttag > $corpus_ttagged
fi

if [ $DO_DICT == 1 ]; then
# Extract dictionary of moses-tokenized corpus
    $IRSTLM/bin/dict -i=$corpus_tok -o=$corpus_dict -c=yes 
fi

if [ $DO_POS_MAPPING == 1 ]; then
    perl $HYBRIDLM/make-POS-mapping.pl --ttagged=$corpus_ttagged --dict=$corpus_dict \
	$posmap_params $lg_param $lemma_param \
	> $word_tag_map
	if [ $USE_LEMMA == "yes" ]; then
		mv $word_tag_map $word_tag_lemma_map
	fi
fi

if [ $DO_LEMMA_DICT == 1 ]; then
    # lemmatize training corpus
    perl $HYBRIDLM/applyWordMapping.pl --map=$word_tag_lemma_map --field=2 \
	< $corpus_tok > $corpus_tok.lemma

    # compute dict-freq of lemmatized corpus
    $IRSTLM/bin/dict -i=$corpus_tok.lemma -o=$corpus_tok.lemma.dict -c=yes
fi

if [ $DO_HYBRID_MAPPING == 1 ]; then
    # create hybrid mapping
    if [ $USE_LEMMA == "yes" ]; then
	perl $HYBRIDLM/make-hybrid-mapping.pl --map=$word_tag_lemma_map --dict=$corpus_dict --minfreq=${MINFREQ} \
	    $lemma_param --dict2=$corpus_tok.lemma.dict \
	    $hybmap_params \
	    > $word_tag_map.$hybmap_suff$probWG_suff
    else
	perl $HYBRIDLM/make-hybrid-mapping.pl --map=$word_tag_map --dict=$corpus_dict --minfreq=${MINFREQ} \
	    $hybmap_params \
	    > $word_tag_map.$hybmap_suff$probWG_suff
    fi
fi

if [ $DO_MAP_CORPUS == 1 ]; then
    perl $HYBRIDLM/applyWordMapping.pl --map=$word_tag_map.$hybmap_suff$probWG_suff \
	< $corpus_tok > $corpus_tok.$hybmap_suff
fi

if [ $DO_SENT == 1 ]; then
    sh $IRSTLM/scripts/add-start-end.sh <  $corpus_tok.$hybmap_suff >  $corpus_tok.$hybmap_suff.snt
fi